@@ -30,10 +30,12 @@
 #include "atspi-event-listener-private.h"
 #include "atspi-matchrule-private.h"
 #include "atspi-misc-private.h"
+#include "atspi-mutter-private.h"
 
 #include "glib/gi18n.h"
 
 #include "atspi.h"
+#include "atspi-accessible-private.h"
 
 G_BEGIN_DECLS
 void _atspi_reregister_device_listeners ();
